more work on the XML catalog support. small cleanup seems using list as a

* Makefile.am catalog.c xmlcatalog.c include/libxml/catalog.h:
  more work on the XML catalog support.
* parser.c include/libxml/parser.h: small cleanup seems using
  list as a public parameter name can give portability troubles
* trionan.c trionan.h xpath.c include/libxml/trionan.h
  include/libxml/xpath.h include/libxml/Makefile.am: removed
  trionan from the libxml API, added xmlXPathIsInf and xmlXPathIsNaN
  wrappers
Daniel
diff --git a/parser.c b/parser.c
index 9aa091c..64b55b5 100644
--- a/parser.c
+++ b/parser.c
@@ -8921,7 +8921,7 @@
  * @ctx:  the existing parsing context
  * @URL:  the URL for the entity to load
  * @ID:  the System ID for the entity to load
  * @list:  the return value for the set of parsed nodes
  *
  * Parse an external general entity within an existing parsing context
  * An external general parsed entity is well-formed if it matches the
@@ -8935,7 +8935,7 @@
 
 int
 xmlParseCtxtExternalEntity(xmlParserCtxtPtr ctx, const xmlChar *URL,
-	               const xmlChar *ID, xmlNodePtr *list) {
+	               const xmlChar *ID, xmlNodePtr *lst) {
     xmlParserCtxtPtr ctxt;
     xmlDocPtr newDoc;
     xmlSAXHandlerPtr oldsax = NULL;
@@ -8947,8 +8947,8 @@
 	return(XML_ERR_ENTITY_LOOP);
     }
 
-    if (list != NULL)
-        *list = NULL;
+    if (lst != NULL)
+        *lst = NULL;
     if ((URL == NULL) && (ID == NULL))
 	return(-1);
     if (ctx->myDoc == NULL) /* @@ relax but check for dereferences */
@@ -9065,7 +9065,7 @@
 	else
 	    ret = ctxt->errNo;
     } else {
-	if (list != NULL) {
+	if (lst != NULL) {
 	    xmlNodePtr cur;
 
 	    /*
@@ -9073,7 +9073,7 @@
 	     * they pseudo parent.
 	     */
 	    cur = newDoc->children->children;
-	    *list = cur;
+	    *lst = cur;
 	    while (cur != NULL) {
 		cur->parent = NULL;
 		cur = cur->next;
@@ -9282,7 +9282,7 @@
  * @depth:  Used for loop detection, use 0
  * @URL:  the URL for the entity to load
  * @ID:  the System ID for the entity to load
  * @list:  the return value for the set of parsed nodes
  *
  * Parse an external general entity
  * An external general parsed entity is well-formed if it matches the
@@ -9296,9 +9296,9 @@
 
 int
 xmlParseExternalEntity(xmlDocPtr doc, xmlSAXHandlerPtr sax, void *user_data,
-	  int depth, const xmlChar *URL, const xmlChar *ID, xmlNodePtr *list) {
+	  int depth, const xmlChar *URL, const xmlChar *ID, xmlNodePtr *lst) {
     return(xmlParseExternalEntityPrivate(doc, NULL, sax, user_data, depth, URL,
-		                       ID, list));
+		                       ID, lst));
 }
 
 /**
@@ -9308,7 +9308,7 @@
  * @user_data:  The user data returned on SAX callbacks (possibly NULL)
  * @depth:  Used for loop detection, use 0
  * @string:  the input string in UTF8 or ISO-Latin (zero terminated)
  * @list:  the return value for the set of parsed nodes
  *
  * Parse a well-balanced chunk of an XML document
  * called by the parser
@@ -9323,7 +9323,7 @@
 
 int
 xmlParseBalancedChunkMemory(xmlDocPtr doc, xmlSAXHandlerPtr sax,
-     void *user_data, int depth, const xmlChar *string, xmlNodePtr *list) {
+     void *user_data, int depth, const xmlChar *string, xmlNodePtr *lst) {
     xmlParserCtxtPtr ctxt;
     xmlDocPtr newDoc;
     xmlSAXHandlerPtr oldsax = NULL;
@@ -9335,8 +9335,8 @@
     }
 
 
-    if (list != NULL)
-        *list = NULL;
+    if (lst != NULL)
+        *lst = NULL;
     if (string == NULL)
         return(-1);
 
@@ -9418,7 +9418,7 @@
 	else
 	    ret = ctxt->errNo;
     } else {
-	if (list != NULL) {
+	if (lst != NULL) {
 	    xmlNodePtr cur;
 
 	    /*
@@ -9426,7 +9426,7 @@
 	     * they pseudo parent.
 	     */
 	    cur = newDoc->children->children;
-	    *list = cur;
+	    *lst = cur;
 	    while (cur != NULL) {
 		cur->parent = NULL;
 		cur = cur->next;
@@ -8921,7 +8921,7 @@
  * @URL:  the URL for the entity to load
  * @ID:  the System ID for the entity to load
- * @list:  the return value for the set of parsed nodes
+ * @lst:  the return value for the set of parsed nodes
  *
  * Parse an external general entity within an existing parsing context
@@ -9282,7 +9282,7 @@
  * @URL:  the URL for the entity to load
  * @ID:  the System ID for the entity to load
- * @list:  the return value for the set of parsed nodes
+ * @lst:  the return value for the set of parsed nodes
  *
  * Parse an external general entity
@@ -9308,7 +9308,7 @@
  * @depth:  Used for loop detection, use 0
  * @string:  the input string in UTF8 or ISO-Latin (zero terminated)
- * @list:  the return value for the set of parsed nodes
+ * @lst:  the return value for the set of parsed nodes
  *
  * Parse a well-balanced chunk of an XML document